#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

function enable_gpu_plugin() {
  if kubectl -n kube-system get daemonset nvidia-device-plugin-daemonset &>/dev/null;
  then
    info "Rollout daemonset nvidia-device-plugin-daemonset"
    # in case of non-primary nodes, we need to restart daemonset, as sometimes it does not pick up the containerd changes
    kubectl -n kube-system rollout restart daemonset nvidia-device-plugin-daemonset
    info "Rollout daemonset nvidia-device-plugin-daemonset Successfully."
  else
    info "Deploy daemonset nvidia-device-plugin-daemonset"
    rm -f "${SCRIPT_DIR}/Infra_Installer/gpu_plugin/nvidia-device-plugin-tmp.yaml" &>/dev/null
    cp "${SCRIPT_DIR}/Infra_Installer/gpu_plugin/nvidia-device-plugin.yaml" "${SCRIPT_DIR}/Infra_Installer/gpu_plugin/nvidia-device-plugin-tmp.yaml"
    DOCKER_REGISTRY_CONFIG=$(cat < /etc/rancher/rke2/registries.yaml | grep -A1 "configs:"|tail -n1| awk '{print $0}'|tr -d ' '|tr -d '"')
    DOCKER_REGISTRY_URL="${DOCKER_REGISTRY_CONFIG::-1}"
    sed -i "s/REGISTRY_PLACEHOLDER/${DOCKER_REGISTRY_URL}/g" "${SCRIPT_DIR}/Infra_Installer/gpu_plugin/nvidia-device-plugin-tmp.yaml"
    kubectl apply -f "${SCRIPT_DIR}/Infra_Installer/gpu_plugin/nvidia-device-plugin-tmp.yaml"  1>/dev/null
    info "Deploy daemonset nvidia-device-plugin-daemonset successfully."
  fi
}

function disable_gpu_plugin() {
  info "Delete daemonset nvidia-device-plugin-daemonset"
  kubectl delete -f "${SCRIPT_DIR}/Infra_Installer/gpu_plugin/nvidia-device-plugin.yaml"  1>/dev/null
  info "Delete daemonset nvidia-device-plugin-daemonset successfully."
}