## How to add Testrail tests:

1. Get the test IDs that you want to test from [testrail](https://uipath.testrail.com/index.php?/suites/view/1640&group_by=cases:section_id&group_order=asc&display_deleted_cases=0). The ID should not contain the C, only the number. For example, [this](https://uipath.testrail.com/index.php?/cases/view/1524287&group_by=cases:section_id&group_order=asc&display_deleted_cases=0&group_id=161238) case has ID `1524287`. You can have multiple testrail tests in the same pipeline script.

2. Create an ansible `yml` file in the `Tests/Test_Rail/Tests` based on a previous (similar) example. Please keep the below configuration:
```yml
    register: run_test
    failed_when: run_test.rc != 0
```
The examples already created use PowerShell inline. You could create a powershell script and call it inline if the test is too big. 

---
**NOTE**

Please make sure that you exit with a code in accordance to the test's result, failed (!=0) or successful (==0) using a condition. See this example:
```powershell
if ((Get-Content -tail 10 output.txt) -like "*UiPath Services installed successfully.*") 
    {
        Write-Output "Received correct error message test successful!"
        exit
    }
    else {
        exit 1
    }
```

The `yml` file will might contain several ansible tasks in accordance to the commands executed on the cluster nodes. For example a normal multi-node installation will consist of `infra` being installed on all nodes and then `fabric` and `services` on the first one.

---

3. Create a new entry in the file `Tests/Test_Rail/tests.json`. This file is an array of tests that will be executed. It has the following structure:
```json
{
    "TestName": "Validate single node successful install with -a",
    "TestSuite": "SingleNodeOnline",
    "Entrypoint": "SingleNodeSuccessfulInstall.yml",
    "TestRailCasesValidatedByRun": [
      "1524279"
    ]
}
```
where:
- TestName: the name of the test that will show up in the pipeline tests
- TestSuite: the suite of the tests that will have these values:
    - SingleNodeOnline
    - MultiNodeOnline
    - SingleNodeOffline
    - MultiNodeOffline
- Entrypoint: the name of the file that you created at step 2
- TestRailCasesValidatedByRun: the cases that will be validated by the script (step 1)