

function testMonitoringPodCount() {
    local podCount expectedPodCount replicaCount validTestRailIds requestedTestRailIds expectedPrometheusNodeExporterPodCount

    expectedPodCount=$1
    expectedPrometheusNodeExporterPodCount=$2
    requestedTestRailIds=$3
    validTestRailIds=("1621316" "1621317" "1663793" "1663801")

    for validTestRailId in "${validTestRailIds[@]}"; do
        if [[ "${requestedTestRailIds}" =~ "${validTestRailId}" ]]; then
            result="false";
            replicaCount=$(fetchReplicaCount statefulset cattle-monitoring-system alertmanager-rancher-monitoring-alertmanager)
            if [[ -z $replicaCount && -z $expectedPodCount && -z $expectedPrometheusNodeExporterPodCount ]]; then
                result="true"
                appendOutput "${validTestRailId}" "${result}"
                return
            fi
            podCount=$(kubectl -n cattle-monitoring-system get pods --field-selector=status.phase=Running --selector=app=alertmanager --output json | jq -j ".items | length")
            if [[ ${podCount} -ge ${expectedPodCount} && ${podCount} -le ${replicaCount} ]]; then
                result="true"
            fi

            replicaCount=$(fetchReplicaCount deploy cattle-monitoring-system rancher-monitoring-grafana)
            podCount=$(kubectl -n cattle-monitoring-system get pods --field-selector=status.phase=Running --selector=app.kubernetes.io/name=grafana --output json | jq -j ".items | length")
            if [[ ${podCount} -ge ${expectedPodCount} && ${podCount} -le ${replicaCount} && "${result}" == "true" ]]; then
                result="true"
            fi

            replicaCount=$(fetchReplicaCount statefulset prometheus-rancher-monitoring-prometheus)
            podCount=$(kubectl -n cattle-monitoring-system get pods --field-selector=status.phase=Running --selector=app.kubernetes.io/name=prometheus --output json | jq -j ".items | length")
            if [[ ${podCount} -ge ${expectedPodCount} && ${podCount} -le ${replicaCount} && "${result}" == "true" ]]; then
                result="true"
            fi

            podCount=$(kubectl -n cattle-monitoring-system get pods --field-selector=status.phase=Running --selector=app=prometheus-node-exporter --output json | jq -j ".items | length")
            if [[ ${podCount} -ge ${expectedPrometheusNodeExporterPodCount} && "${result}" == "true" ]]; then
                result="true"
            fi
            appendOutput "${validTestRailId}" "${result}"
        fi
    done  
}

function setMonitoringValidationParam() {
    local validationStage
    validationStage=$1
    case "$validationStage" in
    3nodeup)
        monitoringPodCount=2
        expectedPrometheusNodeExporterPodCount=3
        testRailIds="1621316"
        ;;
     rebootAllServers)
        monitoringPodCount=2
        expectedPrometheusNodeExporterPodCount=3
        testRailIds="1621317"
        ;;
    2nodeup)
        monitoringPodCount=2
        expectedPrometheusNodeExporterPodCount=2
        testRailIds="1663793"
        ;;
    1nodeup|0nodeup)
        monitoringPodCount=""
        expectedPrometheusNodeExporterPodCount=""
        testRailIds="1663801"
        ;;
    *)
        echo "Unexpected option ${validationStage} passed to ${FUNCNAME[0]}"
        exit 1
        ;;
    esac

}

function executeMonitoringTest() {
    setMonitoringValidationParam "${VALIDATE_STAGE}"
    testMonitoringPodCount "${monitoringPodCount}" "${expectedPrometheusNodeExporterPodCount}" "${testRailIds}"
}