#!/bin/bash

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)

if [[ -z "${SCRIPT_DIR}" ]]; then
    echo "Script dir not present"
    exit 1
fi

#shellcheck disable=SC1090,SC1091
source "${SCRIPT_DIR}/utils.sh"

function check_replicas() {
    DESIRED_REPLICAS=$(kubectl -n "$2" get deploy "$1" -o json | jq .status.replicas)
    READY_REPLICAS=$(kubectl -n "$2" get deploy "$1" -o json | jq .status.readyReplicas)
    if [[ "${READY_REPLICAS}" = "${DESIRED_REPLICAS}" ]];
    then
        echo "UP"
    elif [[ "${READY_REPLICAS}" = "0" ]];
    then
        echo "DOWN"
    fi
}

function main() {
    deployments=$(kubectl -n argocd get deploy --no-headers -o custom-columns=NAME:.metadata.name)
    isdeploymentdown="false"
    for deploy in $deployments;
    do
        status=$(check_replicas "$deploy" "argocd")
        if [[ "${status}" == "UP" ]];
        then
            echo "Deployment $deploy is up"
        else
            echo "Deployment $deploy is down"
            isdeploymentdown="true"
        fi
    done

    if [[ "${isdeploymentdown}" == "true" ]];
    then
        mark_test_failed 1648636 /tmp/test_results.json
    else
        mark_test_passed 1648636 /tmp/test_results.json
    fi
}

main